@@ -7,13 +7,6 @@ class ConfigFetcher(object):
     """
     __metaclass__ = ABCMeta
 
-    @abstractmethod
-    def __init__(self, project_secret):
-        """
-        Initializes the ConfigFetcher
-        :param project_secret: The project's Project Secret
-        """
-
     @abstractmethod
     def get_configuration_json(self):
         """
@@ -27,29 +20,49 @@ class ConfigFetcher(object):
         """
 
 
-class ConfigStore(object):
+class ConfigCache(object):
     """
-        Cache interface
+        Config cache interface
     """
     __metaclass__ = ABCMeta
 
     @abstractmethod
-    def __init__(self, config_fetcher):
+    def get(self):
         """
-        Initializes the store with a config_fetcher
-        :param config_fetcher: The ConfigFetcher implementation for fetching the configuration from BetterConfig
+        :returns the config json object from the cache
         """
 
+    @abstractmethod
+    def set(self, value):
+        """
+        Sets the config json cache.
+        """
+
+
+class CachePolicy(object):
+    """
+        Config cache interface
+    """
+    __metaclass__ = ABCMeta
+
     @abstractmethod
     def get(self):
         """
-        Gets the config json object
+        :returns the config json object from the cache
         """
 
     @abstractmethod
-    def invalidate_cache(self):
+    def force_refresh(self):
         """
-        Invalidates the config cache
+
+        :return:
+        """
+
+    @abstractmethod
+    def stop(self):
+        """
+
+        :return:
         """
 
 
